<?php

/**
 * HTMLmail plugin
 *
 *
 * Created: 2007-02-17
 * Last update: 2007-02-17
 *
 * @link http://deboutv.free.fr/mantis/
 * @author DEBOUT Vincent  <deboutv@free.fr>
 */

/** 
 * Constant definitions
 */
define( 'PLUGINS_HTMLMAIL_FORMAT_TEXT', 0 );
define( 'PLUGINS_HTMLMAIL_FORMAT_HTML', 1 );
define( 'PLUGINS_HTMLMAIL_FORMAT_TEXT_HTML', 2 );
define( 'PLUGINS_HTMLMAIL_FORMAT_DEFAULT', PLUGINS_HTMLMAIL_FORMAT_TEXT );

/** 
 * This function is used to build and store the email
 *
 * @param mixed $p_visible_bug_data Bug information
 * @param string $p_message_id The message
 * @param int $p_project_id The project id
 * @param int $p_user_id The user id
 * @param mixed $p_header_optional_params Optional header
 * @return bool
 */
function email_bug_info_to_one_user( $p_visible_bug_data, $p_message_id, $p_project_id, $p_user_id, $p_header_optional_params = null ) {
    $t_user_email = user_get_email( $p_user_id );

    if ( ON !== config_get( 'enable_email_notification' ) || is_blank( $t_user_email ) ) {
        return true;
    }

    $t_subject = '['.$p_visible_bug_data['email_project'].' '
      .bug_format_id( $p_visible_bug_data['email_bug'] )
        .']: '.$p_visible_bug_data['email_summary'];

    $t_message = lang_get_defaulted( $p_message_id, null );

    if ( is_array( $p_header_optional_params ) ) {
        $t_message = vsprintf( $t_message, $p_header_optional_params );
    }

    $t_message_id = $t_message;

    if ( ( $t_message !== null ) && ( !is_blank( $t_message ) ) ) {
        $t_message .= " \n";
    }

    $t_message .= email_format_bug_message(  $p_visible_bug_data );

    $t_recipient = trim( $t_user_email );
    $t_subject = string_email( trim( $t_subject ) );
    $t_message = string_email_links( trim( $t_message ) );
    if ( is_blank( $t_recipient ) || ( OFF == config_get( 'enable_email_notification' ) ) ) {
        return;
    }
    $t_email_data = new EmailData;

    $t_email_data->email = $t_recipient;
    $t_email_data->subject = $t_subject;
    $t_email_data->body = $t_message;
    $t_email_data->metadata = array();
    $t_email_data->metadata['headers'] = array( 'keywords' => $p_visible_bug_data['set_category'] );
    $t_email_data->metadata['priority'] = config_get( 'mail_priority' );
    $t_email_data->metadata['charset'] =  lang_get( 'charset', lang_get_current() );
    $t_email_data->metadata['plugins_htmlmail_user_id'] = $p_user_id;
    $t_email_data->metadata['plugins_htmlmail_project_id'] = $p_project_id;
    $t_email_data->metadata['plugins_htmlmail_message_id'] = $t_message_id;
    $t_email_data->metadata['plugins_htmlmail_id'] = $p_visible_bug_data['email_bug'];
    $t_email_id = email_queue_add( $t_email_data );
    return $t_email_id; 
}

/** 
 * The new email_send function used to send email to the
 * correct format (text, HTML or text/HTML).
 * This function returns true if success, false otherwise.
 *
 * @param mixed $p_email_data The email data structure
 * @return bool
 */
function email_send( $p_email_data ) {
    global $g_phpMailer_smtp;

    $t_email_data = $p_email_data;

    $t_is_html = false;
    $t_format = PLUGINS_HTMLMAIL_FORMAT_TEXT;
    $t_user_realname = '';
    if ( isset( $t_email_data->metadata['plugins_htmlmail_id'] ) ) {
        $t_id = $t_email_data->metadata['plugins_htmlmail_id'];
        $t_user_id = $t_email_data->metadata['plugins_htmlmail_user_id'];
        $t_user_realname = user_get_realname( $t_user_id );
        $t_project_id = $t_email_data->metadata['plugins_htmlmail_project_id'];
        $t_message_id = $t_email_data->metadata['plugins_htmlmail_message_id'];
        $t_format = config_get( 'plugins_htmlmail_format', PLUGINS_HTMLMAIL_FORMAT_DEFAULT, $t_user_id, $t_project_id );
        if ( $t_format == PLUGINS_HTMLMAIL_FORMAT_HTML || $t_format == PLUGINS_HTMLMAIL_FORMAT_TEXT_HTML ) {
            $t_is_html = true;
            $t_bug_html = dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'print_bug_inc.php';
            lang_push( user_pref_get_language( $t_user_id ) );
            ob_start();
            include( $t_bug_html );
            $t_html_body = ob_get_contents();
            ob_end_clean();
            lang_pop();
        }
    }

    $t_recipient = trim( $t_email_data->email );
    $t_subject   = string_email( trim( $t_email_data->subject ) );
    $t_message   = string_email_links( trim( $t_email_data->body ) );

    $t_debug_email = config_get( 'debug_email' );

    $t_mail = new PHPMailer;

    $t_mail->PluginDir = PHPMAILER_PATH;

    $t_mail->SetLanguage( lang_get( 'phpmailer_language', config_get( 'default_language' ) ), PHPMAILER_PATH . 'language' . DIRECTORY_SEPARATOR );

    switch ( config_get( 'phpMailer_method' ) ) {
      case 0: $t_mail->IsMail();
        break;

      case 1: $t_mail->IsSendmail();
        break;

      case 2: $t_mail->IsSMTP();
        {
            $t_mail->SMTPKeepAlive = true;

            if( is_null( $g_phpMailer_smtp ) )  {
                register_shutdown_function( 'email_smtp_close' );
            } else {
                $t_mail->smtp = $g_phpMailer_smtp;
            }
        }
        break;
    }

    $t_mail->IsHTML( $t_is_html );
    $t_mail->WordWrap = 80;
    $t_mail->Priority = $t_email_data->metadata['priority'];
    $t_mail->CharSet = $t_email_data->metadata['charset'];
    $t_mail->Host     = config_get( 'smtp_host' );
    $t_mail->From     = config_get( 'from_email' );
    $t_mail->Sender   = config_get( 'return_path_email' );
    $t_mail->FromName = '';

    if ( !is_blank( config_get( 'smtp_username' ) ) ) {
        $t_mail->SMTPAuth = true;
        $t_mail->Username = config_get( 'smtp_username' );
        $t_mail->Password = config_get( 'smtp_password' );
    }

    if ( OFF !== $t_debug_email ) {
        $t_message = 'To: '. $t_recipient . "\n\n" . $t_message;
        $t_mail->AddAddress( $t_debug_email, '' );
    } else {
        $t_mail->AddAddress( $t_recipient, $t_user_realname );
    }

    $t_mail->Subject = $t_subject;
    if ( $t_is_html ) {
        $t_mail->Body = $t_html_body;
    } else {
        $t_mail->Body = make_lf_crlf( "\n" . $t_message );
    }
    if ( $t_format == PLUGINS_HTMLMAIL_FORMAT_TEXT_HTML ) {
        $t_mail->AltBody = make_lf_crlf( "\n" . $t_message );
    }

    if ( isset( $t_email_data->metadata['headers'] ) && is_array( $t_email_data->metadata['headers'] ) ) {
        foreach ( $t_email_data->metadata['headers'] as $t_key => $t_value ) {
            $t_mail->AddCustomHeader( "$t_key: $t_value" );
        }
    }

    if ( !$t_mail->Send() ) {
        $t_success = false;
    } else {
        $t_success = true;

        if ( $t_email_data->email_id > 0 ) {
            email_queue_delete( $t_email_data->email_id );
        }
    }

    if ( !is_null( $t_mail->smtp ) )  {
        $g_phpMailer_smtp = $t_mail->smtp;
    }

    return $t_success;
}

?>
